summaryrefslogtreecommitdiffstats
path: root/kdat/File.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 20:34:22 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 20:34:22 +0000
commitb09bffed6b43262948018dfb0f11890850ddf7c1 (patch)
tree138696bfcc7ac01070d0e8ecaa1cdf94611a2bd8 /kdat/File.h
parent6d43944a7130b9d1b4ae3fba37b774aced8612cf (diff)
downloadtdeadmin-b09bffed6b43262948018dfb0f11890850ddf7c1.tar.gz
tdeadmin-b09bffed6b43262948018dfb0f11890850ddf7c1.zip
TQt4 port kdeadmin
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeadmin@1237416 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdat/File.h')
-rw-r--r--kdat/File.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kdat/File.h b/kdat/File.h
index 75b1d87..7bfcd3e 100644
--- a/kdat/File.h
+++ b/kdat/File.h
@@ -46,13 +46,13 @@ class File {
} _union;
TQString _name;
File* _parent;
- TQPtrList<File> _children;
+ TQPtrList<File> _tqchildren;
RangeList _ranges;
public:
/**
* Create a new file entry.
*
* @param parent The directory file entry that contains this file.
* @param size The size of the file in bytes.
* @param mtime The last modification time of the file in seconds since
* the Epoch.
@@ -63,24 +63,24 @@ public:
* the file's path name should be passed in. The rest of the
* path is determined by this file entry's ancestors.
*/
- File( File* parent, int size, int mtime, int startRecord, int endRecord, const TQString & name );
+ File( File* tqparent, int size, int mtime, int startRecord, int endRecord, const TQString & name );
/**
* Create a new stubbed instance of a file entry. The file pointer and
* offset specify where the actual instance data can be found. The real
* data is read on demand when one of the accessor functions is called.
*
* @param parent The directory file entry that contains this file.
* @param fptr The open index file containing this file entry. The file
* must be left open so that the file entry information can
* be read at a later time.
* @param offset The offset that will be seeked to when reading the file
* entry information.
*/
- File( File* parent, FILE* fptr, int offset );
+ File( File* tqparent, FILE* fptr, int offset );
/**
* Destroy the file entry and all of its children.
*/
~File();
@@ -95,7 +95,7 @@ public:
/**
* Recursively read the instance for this file entry and all of it's
* children. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
*/
@@ -103,7 +103,7 @@ public:
/**
* Write out the file entry to the open file. Entries for each of its
* children will also be written.
*/
void write( FILE* fptr );
@@ -163,7 +163,7 @@ public:
TQString getFullPathName();
/**
* Get the file entry's parent. A NULL parent indicates that this is one
* of (possibly) many top level directories within the tar archive.
*
* @return A pointer to the file entry that contains this file entry.
@@ -171,15 +171,15 @@ public:
File* getParent();
/**
* Get the children of this file entry. A normal file will never have any
* children. A directory may or may not have children.
*
* @return A list of the immediate children of this file entry.
*/
const TQPtrList<File>& getChildren();
/**
* Get the list of ranges of this file and all of its children.
*
* @return A list of ranges.
*/
@@ -193,7 +193,7 @@ public:
void addChild( File* file );
/**
* Recursively calculate the list of ranges for all of the file's children.
*/
void calcRanges();
};
@@ -46,13 +46,13 @@ class File {
* Create a new file entry.
*
- * @param parent The directory file entry that contains this file.
+ * @param tqparent The directory file entry that contains this file.
* @param size The size of the file in bytes.
* @param mtime The last modification time of the file in seconds since
@@ -63,24 +63,24 @@ public:
* data is read on demand when one of the accessor functions is called.
*
- * @param parent The directory file entry that contains this file.
+ * @param tqparent The directory file entry that contains this file.
* @param fptr The open index file containing this file entry. The file
* must be left open so that the file entry information can
@@ -63,24 +63,24 @@ public:
/**
- * Destroy the file entry and all of its children.
+ * Destroy the file entry and all of its tqchildren.
*/
~File();
@@ -95,7 +95,7 @@ public:
/**
* Recursively read the instance for this file entry and all of it's
- * children. This method is used when converting from an older index format.
+ * tqchildren. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
@@ -103,7 +103,7 @@ public:
/**
* Write out the file entry to the open file. Entries for each of its
- * children will also be written.
+ * tqchildren will also be written.
*/
void write( FILE* fptr );
@@ -163,7 +163,7 @@ public:
TQString getFullPathName();
/**
- * Get the file entry's parent. A NULL parent indicates that this is one
+ * Get the file entry's tqparent. A NULL tqparent indicates that this is one
* of (possibly) many top level directories within the tar archive.
*
@@ -171,15 +171,15 @@ public:
File* getParent();
/**
- * Get the children of this file entry. A normal file will never have any
- * children. A directory may or may not have children.
+ * Get the tqchildren of this file entry. A normal file will never have any
+ * tqchildren. A directory may or may not have tqchildren.
*
@@ -171,15 +171,15 @@ public:
*
- * @return A list of the immediate children of this file entry.
+ * @return A list of the immediate tqchildren of this file entry.
*/
const TQPtrList<File>& getChildren();
@@ -171,15 +171,15 @@ public:
const TQPtrList<File>& getChildren();
/**
- * Get the list of ranges of this file and all of its children.
+ * Get the list of ranges of this file and all of its tqchildren.
*
* @return A list of ranges.
@@ -193,7 +193,7 @@ public:
void addChild( File* file );
/**
- * Recursively calculate the list of ranges for all of the file's children.
+ * Recursively calculate the list of ranges for all of the file's tqchildren.
*/
void calcRanges();